Struct SigningKey

pub struct SigningKey<P: ParameterSet> { /* private fields */ }
A SigningKey allows signing messages with a fixed parameter set

Implementations

Source

impl<P: ParameterSet> SigningKey<P>

pub fn new(rng: &mut impl CryptoRngCore) -> Self

Create a new SigningKey from a cryptographic random number generator

pub fn try_sign_with_context( &self, msg: &[u8], ctx: &[u8], opt_rand: Option<&[u8]>, ) -> Result<Signature<P>, Error>

Implements [slh-sign] as defined in FIPS-205, using a context string. Context strings must be 255 bytes or less.

Errors

Returns an error if the context string is too long.

pub fn to_bytes(&self) -> Array<u8, P::SkLen>

Serialize the signing key to a new stack-allocated array

This clones the underlying fields

pub fn to_vec(&self) -> Vec<u8>
where P: VerifyingKeyLen,

Serialize the signing key to a new heap-allocated vector