pub struct SigningKey<P: ParameterSet> { /* private fields */ }Expand description
A SigningKey allows signing messages with a fixed parameter set
Implementations
Sourceimpl<P: ParameterSet> SigningKey<P>
impl<P: ParameterSet> SigningKey<P>
Sourcepub fn new(rng: &mut impl CryptoRngCore) -> Self
pub fn new(rng: &mut impl CryptoRngCore) -> Self
Create a new SigningKey from a cryptographic random number generator
Sourcepub fn try_sign_with_context(
&self,
msg: &[u8],
ctx: &[u8],
opt_rand: Option<&[u8]>,
) -> Result<Signature<P>, Error>
pub fn try_sign_with_context( &self, msg: &[u8], ctx: &[u8], opt_rand: Option<&[u8]>, ) -> Result<Signature<P>, Error>
Implements [slh-sign] as defined in FIPS-205, using a context string. Context strings must be 255 bytes or less.
Errors
Returns an error if the context string is too long.